pilas.habilidades.MoverseComoCoche

Package pilas :: Module habilidades :: Class MoverseComoCoche |
[hide private]
[frames] | no frames]

# Class MoverseComoCoche

source code

         object --+
                  |
          Habilidad --+
                      |
    MoverseConElTeclado --+
                          |
                         MoverseComoCoche

Hace que un actor se mueva como un coche.

Instance Methods | [hide private]
__init__(self, receptor, control=None, velocidad_maxima=4, aceleracion=0.06, deceleracion=0.1, rozamiento=0) Inicializa la habilidad. | source code
set_rozamiento(self, nivel_rozamiento) | source code
get_rozamiento(self) | source code
set_velocidad_maxima(self, velocidad) | source code
get_velocidad_maxima(self) | source code
Inherited from `MoverseConElTeclado`: `avanzar`, `decelerar`, `get_aceleracion`, `on_key_press`, `set_aceleracion` Inherited from `Habilidad`: `actualizar`, `eliminar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `MoverseConElTeclado`: `CUATRO_DIRECCIONES`, `OCHO_DIRECCIONES`

Properties | [hide private]
| rozamiento Define el rozamiento del coche con la superficie por donde circula.
Inherited from `MoverseConElTeclado`: `aceleracion`, `velocidad_maxima` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, receptor, control=None, velocidad_maxima=4, aceleracion=0.06, deceleracion=0.1, rozamiento=0) (Constructor) | source code
Inicializa la habilidad. :param receptor: Referencia al actor que aprenderá la habilidad. :param control: Control al que va a responder para mover el Actor. :param direcciones: Establece si puede mover en cualquier direccion o unicamente en 4 direcciones arriba, abajo, izquierda y derecha. El parametro con_rotacion establece las direcciones a OCHO_DIRECCIONES siempre. :param velocidad_maxima: Velocidad maxima en pixeles a la que se moverá el Actor. :param aceleracion: Indica lo rapido que acelera el actor hasta su velocidad máxima. :param deceleracion: Indica lo rapido que decelera el actor hasta parar. :param con_rotacion: Si deseas que el actor rote pulsando las teclas de izquierda y derecha. :param velocidad_rotacion: Indica lo rapido que rota un actor sobre si mismo. :param marcha_atras: Posibilidad de ir hacia atrás. (True o False) Overrides: object.__init__ (inherited documentation)

### set_velocidad_maxima(self, velocidad) | source code
Overrides: MoverseConElTeclado.set_velocidad_maxima

### get_velocidad_maxima(self) | source code
Overrides: MoverseConElTeclado.get_velocidad_maxima

Property Details | [hide private]

### rozamiento Define el rozamiento del coche con la superficie por donde circula. Get Method: get_rozamiento(self) Set Method: set_rozamiento(self, nivel_rozamiento)